@@ -1,8 +1,9 @@
 use clap::{clap_app, AppSettings};
 use reveal_yaml::*;
+use std::io::{Error, ErrorKind};
 
 #[actix_web::main]
-async fn main() -> std::io::Result<()> {
+async fn main() -> Result<(), Error> {
     let args = clap_app! {
         ("Reveal.yaml Manager") =>
         (version: env!("CARGO_PKG_VERSION"))
@@ -13,8 +14,11 @@ async fn main() -> std::io::Result<()> {
             (about: "Download the Reveal.js resources")
         )
         (@subcommand new =>
-            (alias: "init")
-            (about: "Create a new project")
+            (about: "Create a new project and its directory")
+            (@arg DIR: "Project dir")
+        )
+        (@subcommand init =>
+            (about: "Create a new project from exist directory")
             (@arg DIR: "Project dir")
         )
         (@subcommand serve =>
@@ -22,7 +26,7 @@ async fn main() -> std::io::Result<()> {
             (@arg DIR: "Project dir")
             (@arg PORT: --port +takes_value "Set port")
             (@arg PROJECT: -n --name +takes_value "Set project name")
-            (@arg cache: --cache "Parse once and cached project")
+            (@arg edit: -e --edit "Edit mode, watch the state of the project")
         )
         (@subcommand fmt =>
             (about: "Format the current project")
@@ -38,27 +42,33 @@ async fn main() -> std::io::Result<()> {
         )
     }
     .get_matches();
-    if let Some(_) = args.subcommand_matches("update") {
-        update()?;
+    if args.subcommand_matches("update").is_some() {
+        update().await
     } else if let Some(cmd) = args.subcommand_matches("new") {
+        let path = cmd
+            .value_of("DIR")
+            .ok_or_else(|| Error::new(ErrorKind::InvalidInput, "project path is required"))?;
+        blank(path, true)
+    } else if let Some(cmd) = args.subcommand_matches("init") {
         let path = cmd.value_of("DIR").unwrap_or(".");
-        blank(path)?;
+        blank(path, false)
     } else if let Some(cmd) = args.subcommand_matches("serve") {
         let port = cmd.value_of("PORT").unwrap_or("8080");
         let path = cmd.value_of("DIR").unwrap_or(".");
         let project = cmd.value_of("PROJECT").unwrap_or(ROOT);
-        let cache = cmd.is_present("cache");
-        serve(port.parse().unwrap(), path, project, cache).await?;
+        let edit = cmd.is_present("edit");
+        serve(port.parse().unwrap(), path, project, edit).await
     } else if let Some(cmd) = args.subcommand_matches("fmt") {
         let path = cmd.value_of("DIR").unwrap_or(".");
         let project = cmd.value_of("PROJECT").unwrap_or(ROOT);
         let dry = cmd.is_present("dry");
-        fmt(path, dry, project)?;
+        fmt(path, dry, project)
     } else if let Some(cmd) = args.subcommand_matches("pack") {
         let path = cmd.value_of("DIR").unwrap_or(".");
         let dist = cmd.value_of("DIST").unwrap_or("./package");
         let project = cmd.value_of("PROJECT").unwrap_or(ROOT);
-        pack(path, dist, project)?;
+        pack(path, dist, project).await
+    } else {
+        panic!("invalid input")
     }
-    Ok(())
 }
