@@ -1,5 +1,6 @@
-use reqwest::blocking::get;
+use reqwest::get;
 use std::{
+    env::current_exe,
     fs::File,
     io::{Cursor, Result},
 };
@@ -9,10 +10,10 @@ const REVEAL: &str = "https://github.com/hakimel/reveal.js/archive/master.zip";
 pub(crate) const ARCHIVE: &str = "reveal.js-master";
 
 /// Download the archive from Reveal.js repository.
-pub(crate) fn update() -> Result<()> {
-    let b = get(REVEAL).unwrap().bytes().unwrap();
+pub async fn update() -> Result<()> {
+    let b = get(REVEAL).await.unwrap().bytes().await.unwrap();
     println!("Download archive: {}", REVEAL);
-    let archive = get_archive!();
+    let archive = current_exe()?.with_file_name(format!("{}.zip", ARCHIVE));
     let mut r = ZipArchive::new(Cursor::new(b))?;
     let mut w = ZipWriter::new(File::create(archive)?);
     let dist = format!("{}/dist/", ARCHIVE);
